-- 下架
Lua_MartketOffShelvesWindow = class("Lua_MartketOffShelvesWindow", Lua_SecondSizeWindow)
function Lua_MartketOffShelvesWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_MartketOffShelvesWindow";
	self.skinName = "MarketOffShelvesWindow_skin";
	self.titleText = LanUtil.getValue(121717);
end

function Lua_MartketOffShelvesWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.maxTickTime = 0;

	self.shelvesList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 1107, 481));
	self.shelvesList:setLocation(0, -61, 0);
	self.shelvesList:setListCell(Lua_OffShelvesItem, 112, 1107, 1);

	self:onOffShelvesListUpdate();

	self:addLuaEvent("rMineShelvesInfo", self, self.onOffShelvesListUpdate);
end

function Lua_MartketOffShelvesWindow:onOffShelvesListUpdate()
	self.maxTickTime = 0;
	if self.shelvesList ~= nil then
		local arr = DataCenter.marketData.mineShelvesArr;
		if arr ~= nil then
			local showArr = Array();
			local len = arr:getSize();
			for i = 1, len do 
				if type(arr[i]) ~= "number" then
					showArr:add(arr[i]);
					local num = tonumber(arr[i].left_time);
					if num > 0 and self.maxTickTime < num then
						self.maxTickTime = num;
					end
				end
			end

			if showArr:getSize() <= 0 then
				self:hide();
				return;
			end

			self.maxTickTime = self.maxTickTime - (getTime() - DataCenter.marketData.getMineShelvesInfoTime);
			if self.maxTickTime < 0 then
				self.maxTickTime = 0;
			end

			self.shelvesList:setLuaArrayData(showArr, false);
		end
	end

	if self.maxTickTime > 0 then
		if self.bRegisterTimer == nil or self.bRegisterTimer == false then
			self.bRegisterTimer = true;
			Lua_CommonUtil.addTimer("updateMarketOffShelvesTime", 1, self, self.updateMarketOffShelvesTime, nil, -1);
		end
	else
		self:clearTimer();
	end
end

function Lua_MartketOffShelvesWindow:updateMarketOffShelvesTime()
	self.maxTickTime = self.maxTickTime - 1;

	-- 刷新list数据
	if self.shelvesList ~= nil then
		local arr = self.shelvesList.showList;
		local len = arr:getSize();
		for i = 1, len do 
			arr[i]:updateOffShelvesTime();
		end

		arr = self.shelvesList.hideList;
		len = arr:getSize();
		for i = 1, len do 
			arr[i]:updateOffShelvesTime();
		end
	end

	if self.maxTickTime <= 0 then
		self:clearTimer();
	end
end

function Lua_MartketOffShelvesWindow:clearTimer()
	if self.bRegisterTimer ~= nil and self.bRegisterTimer == true then
		self.bRegisterTimer = false;
		Lua_CommonUtil.removeTimer(self, self.updateMarketOffShelvesTime);
	end
end

function Lua_MartketOffShelvesWindow:dispose()
	if self.shelvesList ~= nil then
		self.shelvesList:dispose()
		self.shelvesList = nil;
	end
	self:clearTimer();
	self:superCall("dispose");
end





--------------------------------------------------





Lua_OffShelvesItem = class("Lua_OffShelvesItem", Lua_ListCell);
function Lua_OffShelvesItem:ctor(p)
	self:superCall("ctor", p, "MarketOffShelvesItem_skin");
end

function Lua_OffShelvesItem:buildShowItem()
	self:superCall("buildShowItem");

	self.item = Lua_ToolImage.new(self.content);
	self.item:setDepth(1);
	self.item:setLocation(-503, 3, 0);

	self.offBtn:addClickFuntion(self, self.onOffBtnClick);
end

function Lua_OffShelvesItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	-- data.market_index; -- 拍卖行索引
	-- data.item_id; -- 物品ID
	-- data.item_amount; -- 物品数量
	-- data.money_type; -- 金钱类型
	-- data.price; -- 单价
	-- data.left_time; -- 剩余时间，如果为0表示到期
	-- data.equip; -- 装备
	local vo = Lua_ToolVo.createToolVo(data.item_id, data.item_amount);
	if vo ~= nil then
		vo:fromServer(data);
		vo.packType = Lua_PackTypeDefine.EQUIP;

		-- vo.star = data.start == nil and 0 or data.start;
		-- vo.equipment = data.equip;
		-- vo.card_level = data.equip.card_level;
		-- vo.wingAttr = data.wing_info.wing_attri;
		self.item.data = vo;
		if vo.subType == Lua_PackTypeDefine.CARD_ITEM then
			self.item:showItemLvl(vo.showLevel);
		else
			self.item:showItemLvl(nil);
		end
		self.itemName.text = vo.colorName;

		local num = vo.zongheForce;
		if num > 0 then
			self.scoreTxt.text = LanUtil.formateStr(LanUtil.getValue(121714), tostring(num));
		else
			self.scoreTxt.text = "";
		end

		num = vo.useLvl;
		if num ~= nil then
			self.lvTxt.text = "LV:"..tostring(num);
		else
			self.lvTxt.text = "";
		end
	end

	self.eachPriceTxt.text = tostring(math.ceil(data.price/data.item_amount));
	self.totalPriceTxt.text = tostring(data.price );
	self:updateOffShelvesTime();
end

-- 下架
function Lua_OffShelvesItem:onOffBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.show(LanUtil.getValue(121419));
		return;
	end
	self.clickTime = getTime();

	if self.data == nil then
		return;
	end

	if DataCenter.neverTip:getNeverValue("Lua_OffShelvesItem") == true then
		Lua_ProxyManager.getProxy("Lua_MarketProxy"):sRemoveByShelves(self.data.market_index);
		return;
	end

	local vo = Lua_ToolVo.createToolVo(self.data.item_id, self.data.item_amount);
	if vo ~= nil then
		local tipData = {};
		tipData.des = LanUtil.formateStr(LanUtil.getValue(121734), vo.colorName);  
		tipData.neverTip = "Lua_OffShelvesItem";
		tipData.owner = self;
		tipData.type = 1;
		tipData.subFun = self.onSureOneFun; -- 确定
		Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipData);
	end
end

function Lua_OffShelvesItem:onSureOneFun()
	if self.data == nil then
		return;
	end

	Lua_ProxyManager.getProxy("Lua_MarketProxy"):sRemoveByShelves(self.data.market_index);
end

function Lua_OffShelvesItem:updateOffShelvesTime()
	if self.data == nil then
		return;
	end

	-- 下架时间
	local num = tonumber(self.data.left_time) - (getTime() - DataCenter.marketData.getMineShelvesInfoTime);
	self.timeTxt.text = TimeTransform.getInstance():transSeconds1(num, true);
end

function Lua_OffShelvesItem:onPlayerSoundClick(go)
end

function Lua_OffShelvesItem:dispose()
	self:superCall("dispose");
end